#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__ = ["name"]
from os.path import abspath, basename, dirname

repo = abspath(dirname(dirname(__file__)))

# default pkgname
name = basename(repo).lower().split(".")[0]


if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["keywords"]
from os.path import abspath, dirname, exists, isfile, join

repo = abspath(dirname(dirname(__file__)))

path = join(repo,"keywords.txt")
if exists(path) and isfile(path):
	# separated by " " space
    keywords = open(path).read().lstrip().rstrip()
else:
    if __name__=="__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__=="__main__":
	for k in __all__:
		if k in globals():
			print("%s: %s" % (k,globals()[k]))




#!/usr/bin/env python
# setuptools setup(...,install_requires=[]) keyword
# checks that the requirements installed
# raise exception if requirements not installed:
# error: Could not find required distribution <name>
# fix - install requirements.txt first:
# 1) pip install -U <name>
# 2) pip install -r requirements.txt; python install setup.py
__all__=["install_requires"]
from os.path import abspath, dirname, exists, join

repo = abspath(dirname(dirname(__file__)))

install_requires = []
for name in ["requirements.txt","requires.txt","install_requires.txt"]:
    file = join(repo,name)
    if exists(file):
        lines = open(file).read().splitlines()
        lines = list(filter(lambda l:l.lstrip().rstrip(),lines))
        install_requires=lines

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["url"]
from os.path import abspath, dirname, exists, isfile, join

repo = abspath(dirname(dirname(__file__)))
if not repo: repo="."

path = join(repo,"url.txt")
if exists(path) and isfile(path):
	url = open(path).read().lstrip().rstrip()
else:
    if __name__=="__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# setuptools setup(...,entry_points=[]) keyword
__all__=["entry_points"]
from os.path import *

repo = abspath(dirname(dirname(__file__)))

# ./entry_points.txt
path = join(repo,"entry_points.txt")
if exists(path) and isfile(path):
    lines = open(path).read().splitlines()
    lines = list(filter(lambda l:l.lstrip().rstrip(),lines))
    entry_points=lines
else:
    if __name__=="__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__=="__main__":
	for k in __all__:
		if k in globals():
			print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["packages"]
import os
from os.path import *

repo = abspath(dirname(dirname(__file__)))

# distname.py/
# distname.py/packages/
# distname.py/packages/pkgname1/
# distname.py/packages/pkgname2/
path = join(repo,"packages")
if exists(path) and isdir(path):
    names = os.listdir(path)
    find = list(map(lambda name:join(path,name),names))
    find = list(filter(lambda path:isdir(path),find))
    find = list(filter(lambda path:exists(join(path,"__init__.py")),find))
    packages = list(map(basename,find))
else:
    if __name__=="__main__":
        print("SKIP: %s/ NOT EXISTS" % path)

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__ = []
import sys
from os.path import *

# __pycache__/ conflict with setuptools
sys.dont_write_bytecode = True  # REQUIRED!

repo = abspath(dirname(__file__))

# repo/setup.py 	- this file
# repo/.setup/*.py 	- python files imported by setup.py
setup = join(repo, ".setup")
if exists(setup) and isdir(setup):
    sys.path.append(setup)
else:
    raise Exception("%s NOT EXISTS" % setup)

if __name__ == "__main__":
    __import__("__setup__")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__ = ["scripts"]
import os
from os.path import *

def valid_script_name(name):
    return name[0] != "." and " " not in name


repo = abspath(dirname(dirname(__file__)))

path = join(repo, "scripts")
if exists(path) and isdir(path):
    listdir = filter(valid_script_name, os.listdir(path))
    find = map(lambda name: join(path, name), listdir)
    files = filter(isfile, find)
    scripts = list(map(lambda name: "scripts/%s" % basename(name), files))
    for script in scripts:
        dst = join("/usr/local/bin/%s" % basename(script))
        if exists(dst) and not isfile(dst):
            print("ERROR: %s EXISTS and NOT FILE" % dst)
else:
    if __name__ == "__main__":
        print("SKIP: %s/ NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))
